# Generated by roxygen2: do not edit by hand

export(add_column)
export(add_parameter)
export(add_row)
export(create_md_col)
export(list_columns)
export(list_parameters)
export(list_rows)
export(mighty_domain)
export(mighty_study)
export(move_column)
export(move_parameter)
export(move_row)
export(populate_core)
export(populate_sparse)
export(remove_columns)
export(remove_parameters)
export(remove_rows)
export(resolve_includes)
export(select_column)
export(select_parameter)
export(select_row)
export(update_column)
export(update_parameter)
export(update_row)
export(validate)
export(write_config)
importFrom(S7,validate)
importFrom(S7schema,write_config)
importFrom(dplyr,.data)
