---
title: "Study specifications"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Study specifications}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

`_study.yml` provides study-level properties for a study directory --- the
study identifier and an optional description. The file structure is defined by a
[JSON-schema](https://json-schema.org) accessible with:

```r
system.file("schema", "study.json", package = "mighty.metadata")
```

Below you can find a detailed description of the structure.

```{r echo=FALSE}
S7schema::document_schema(
  x = system.file("schema", "study.json", package = "mighty.metadata"),
  header_start_level = 1
)
```
