# create_md_col()

    {
      "type": "list",
      "attributes": {
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["table_id", "table_label", "order", "id", "label", "origin", "key", "is_core", "core", "method", "codelist", "format_type", "format_length", "format_display", "comment"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25]
        },
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADAE", "ADSL", "ADSL", "ADSL", "ADSL", "ADSL", "ADSL", "ADSL", "ADSL", "ADVS", "ADVS", "ADVS", "ADVS", "ADVS", "ADVS"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Adverse Events Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Subject-Level Analysis Dataset", "Vital Signs Analysis Dataset", "Vital Signs Analysis Dataset", "Vital Signs Analysis Dataset", "Vital Signs Analysis Dataset", "Vital Signs Analysis Dataset", "Vital Signs Analysis Dataset"]
        },
        {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 1, 2, 3, 4, 5, 6, 7, 8, 1, 2, 3, 4, 5, 6]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["STUDYID", "USUBJID", "AESEQ", "AETERM", "AEDECOD", "AEBODSYS", "ASTDT", "AENDT", "TRTEMFL", "SEX", "RACE", "STUDYID", "USUBJID", "SUBJID", "SITEID", "AGE", "AGEU", "SEX", "RACE", "STUDYID", "USUBJID", "PARAMCD", "PARAM", "AVAL", "AVISITN"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Study Identifier", "Unique Subject Identifier", "Sequence Number", "Reported Term for the Adverse Event", "Dictionary-Derived Term", "Body System or Organ Class", "Analysis Start Date", "Analysis End Date", "Treatment Emergent Flag", "Sex", "Race", "Study Identifier", "Unique Subject Identifier", "Subject Identifier for the Study", "Study Site Identifier", "Age", "Age Units", "Sex", "Race", "Study Identifier", "Unique Subject Identifier", "Parameter Code", "Parameter", "Analysis Value", "Analysis Visit (N)"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", null, null, null, "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor", "Predecessor"]
        },
        {
          "type": "logical",
          "attributes": {},
          "value": [false, true, true, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, true, true, false, false, true]
        },
        {
          "type": "logical",
          "attributes": {},
          "value": [null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, true, true, null, null, null, null, null, null]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["Req", "Req", "Cond", "Req", "Cond", "Cond", "Cond", "Cond", "Cond", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req", "Req"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["AE.STUDYID", "AE.USUBJID", "AE.AESEQ", "AE.AETERM", "AE.AEDECOD", "AE.AEBODSYS", "Derived from AE.AESTDTC", "Derived from AE.AEENDTC", "Derived based on treatment period", "ADSL.SEX", "ADSL.RACE", "DM.STUDYID", "DM.USUBJID", "DM.SUBJID", "DM.SITEID", "DM.AGE", "DM.AGEU", "DM.SEX", "DM.RACE", "VS.STUDYID", "VS.USUBJID", "VS.VSTESTCD", "VS.VSTEST", "VS.VSSTRESN", "VS.VISITNUM"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, "FANCY_CDISC_CODELIST", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, "date", "date", "text", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null]
        },
        {
          "type": "integer",
          "attributes": {},
          "value": ["NA", "NA", "NA", "NA", "NA", "NA", 8, 8, 1, "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA", "NA"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, "date9.", "date9.", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null]
        },
        {
          "type": "character",
          "attributes": {},
          "value": [null, null, null, null, null, null, null, null, "AEs occurring more than 30 days post-treatment are not flagged", null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null]
        }
      ]
    }

