# mighty_study()

    Code
      print(study)
    Message
      <mighty_study/list/S7_object>
      @ mighty: `external_data`
      @ study: `study_id`
      $ ADAE: <mighty_domain>
      $ ADSL: <mighty_domain>
      $ ADVS: <mighty_domain>

