% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mighty.metadata-options.R
\name{mighty.metadata-options}
\alias{mighty.metadata-options}
\title{Options for mighty.metadata}
\description{
\subsection{verbosity_level}{

Verbosity level for functions in mighty.metadata. See \link[zephyr:verbosity_level]{zephyr::verbosity_level} for details.
\itemize{
\item Default: \code{NA_character_}
\item Option: \code{mighty.metadata.verbosity_level}
\item Environment: \code{R_MIGHTY.METADATA_VERBOSITY_LEVEL}
}
}
}
