% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mighty.metadata-options.R
\name{mighty.metadata-options-params}
\alias{mighty.metadata-options-params}
\title{Internal parameters for reuse in functions}
\arguments{
\item{verbosity_level}{Verbosity level for functions in mighty.metadata. See \link[zephyr:verbosity_level]{zephyr::verbosity_level} for details.. Default: \code{NA_character_}.}
}
\description{
Internal parameters for reuse in functions
}
\details{
See \link{mighty.metadata-options} for more information.
}
\keyword{internal}
