% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/y_populate_core.R
\name{populate_core}
\alias{populate_core}
\title{Populate Core Variables}
\usage{
populate_core(x, ...)
}
\arguments{
\item{x}{A \link{mighty_study} or \link{mighty_domain} object.}

\item{...}{Additional arguments passed to methods.}
}
\value{
A modified \link{mighty_study} or \link{mighty_domain} with core variables
added as predecessor columns.
}
\description{
Adds core variables from supplier datasets as predecessor columns to
datasets that use them (marked with \code{usecore = TRUE}).

Note: Currently only accepts core variables from ADSL.
}
\examples{
study <- mighty_study(
  path = system.file("examples", package = "mighty.metadata")
)
study <- populate_core(study)

}
\seealso{
\link{mighty_study}, \code{\link[=populate_sparse]{populate_sparse()}}, \code{\link[=create_md_col]{create_md_col()}}
}
