% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/y_populate_sparse.R
\name{populate_sparse}
\alias{populate_sparse}
\title{Populate Predecessor Metadata}
\usage{
populate_sparse(x, ...)
}
\arguments{
\item{x}{A \link{mighty_study} or \link{mighty_domain} object.}

\item{...}{Additional arguments passed to methods.}
}
\value{
A modified \link{mighty_study} or \link{mighty_domain} with predecessor
column metadata populated.
}
\description{
Populates column metadata from predecessor references. Columns with a
\code{method} in the format \code{domain.column} (e.g., \code{ADSL.USUBJID}) inherit
metadata from the referenced predecessor.
}
\examples{
study <- mighty_study(
  path = system.file("examples", package = "mighty.metadata")
)
study <- populate_sparse(study)

}
\seealso{
\link{mighty_study}, \code{\link[=populate_core]{populate_core()}}, \code{\link[=create_md_col]{create_md_col()}}
}
