% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mighty_domain.R
\name{mighty_domain}
\alias{mighty_domain}
\title{Mighty Domain}
\usage{
mighty_domain(file)
}
\arguments{
\item{file}{\code{character(1)} path to a yaml file defining an ADaM dataset.}
}
\value{
A \code{mighty_domain} S7 object extending \link[S7schema:S7schema]{S7schema::S7schema}.
The underlying list contains the parsed and validated YAML metadata
including \code{id}, \code{label}, \code{class}, \code{keys}, \code{columns}, \code{parameters},
and \code{rows}.
}
\description{
\code{mighty_domain()} provides a robust way of working with ADaM metadata in the \code{{mighty}} framework.

A new object is initialized by supplying an existing yaml metadata file.
This package provides helpers to update column, parameter, and row entries.
See the references below for help:
\itemize{
\item \code{help("columns")}
\item \code{help("parameters")}
\item \code{help("rows")}
}

\code{mighty_domain()} inherits from \code{S7schema::S7schema()} and the yaml file is
automatically validated when loaded. The helper functions above also always validates
the new configuration before returning.

You can at anytime validate an object by calling \code{validate()} and use
\code{write_config()} to save it as a yaml file again.
}
\examples{
x <- mighty_domain(
  file = system.file("examples", "advs.yml", package = "mighty.metadata")
)

# Custom print method gives a small overview
print(x)

# Underlying object is a `list`
str(x)

}
